@@ -1,5 +1,5 @@
 /*
- * $Id: mod_ruby.c 110 2006-02-18 00:35:03Z shugo $
+ * $Id: mod_ruby.c 126 2006-05-27 03:10:03Z shugo $
  * Copyright (C) 2000  ZetaBITS, Inc.
  * Copyright (C) 2000  Information-technology Promotion Agency, Japan
  * Copyright (C) 2001  Shugo Maeda <shugo@modruby.net>
@@ -526,7 +526,7 @@ static void handle_error(request_rec *r, int state)
     errmsg = ruby_get_error_info(state);
     if (r->request_config) {
 	rconf = get_request_config(r);
-	if (!NIL_P(rconf->request_object))
+	if (rconf && !NIL_P(rconf->request_object))
 	    rb_apache_request_set_error(rconf->request_object,
 					errmsg, ruby_errinfo);
     }
@@ -1173,10 +1173,11 @@ static void per_request_cleanup(request_rec *r, int flush)
     rb_set_kcode(default_kcode);
     if (r->request_config) {
 	ruby_request_config *rconf = get_request_config(r);
-	restore_env(r->pool, rconf->saved_env);
+	if (rconf)
+	    restore_env(r->pool, rconf->saved_env);
     }
     rb_progname = Qnil;
-    if (dconf->gc_per_request)
+    if (dconf && dconf->gc_per_request)
 	rb_gc();
 }
 
